@@ -1,14 +1,14 @@
 package Gtk2::CellEditable;
 
-# $Id: CellEditable.pm,v 1.1 2002/11/11 16:55:44 gthyni Exp $
+# $Id: CellEditable.pm,v 1.2 2002/12/16 17:08:23 ggc Exp $
 # Copyright 2002, Gran Thyni, kirra.net
 # licensed with Lesser General Public License (LGPL)
 # see http://www.fsf.org/licenses/lgpl.txt
 
-our $rcsid = '$Id: CellEditable.pm,v 1.1 2002/11/11 16:55:44 gthyni Exp $';
+our $rcsid = '$Id: CellEditable.pm,v 1.2 2002/12/16 17:08:23 ggc Exp $';
 our $VERSION = $1 if $rcsid =~ /(\d+\.[\d\.]+)/;
 
-#BEGIN { do 'Gtk2/_config.pm'; }
+#BEGIN { do 'Gtk2/_config.pm'; $@ and die }
 
 # not a GObject
 use Gtk2::_Object;
