@@ -1,14 +1,14 @@
 package Gtk2::GSignal;
 
-# $Id: GSignal.pm,v 1.18 2002/11/19 13:07:01 ggc Exp $
+# $Id: GSignal.pm,v 1.19 2002/12/16 17:16:25 ggc Exp $
 # Copyright 2002, Gran Thyni, kirra.net
 # licensed with Lesser General Public License (LGPL)
 # see http://www.fsf.org/licenses/lgpl.txt
 
-our $rcsid = '$Id: GSignal.pm,v 1.18 2002/11/19 13:07:01 ggc Exp $';
+our $rcsid = '$Id: GSignal.pm,v 1.19 2002/12/16 17:16:25 ggc Exp $';
 our $VERSION = $1 if $rcsid =~ /(\d+\.[\d\.]+)/;
 
-BEGIN { do 'Gtk2/_config.pm'; }
+BEGIN { do 'Gtk2/_config.pm'; $@ and die }
 
 use Gtk2::GClosure;
 use Gtk2::Gdk::Event;
