@@ -1,4 +1,4 @@
-/* $Id: Cursor.c,v 1.5 2002/10/21 11:41:23 ggc Exp $
+/* $Id: Cursor.c,v 1.6 2003/01/21 12:19:59 ggc Exp $
  * Copyright 2002, Gran Thyni, kirra.net
  * licensed with Lesser General Public License (LGPL)
  * see http://www.fsf.org/licenses/lgpl.txt
@@ -11,7 +11,16 @@ SV* gdkperl_cursor_new(char* class, SV* cursor_type)
     return gtk2_perl_new_object_from_pointer(gdk_cursor_new(SvGdkCursorType(cursor_type)), class);
 }
 
-/* access functions */
+/* GdkCursor* gdk_cursor_ref (GdkCursor *cursor) */
+SV* gdkperl_cursor_ref(SV* cursor)
+{
+    gdk_cursor_ref(SvGdkCursor(cursor));
+    return cursor;
+}
 
-// int gdkperl_cursor_get_type(SV* ge) { return (SvGdkCursor(ge))->type; }
+/* void gdk_cursor_unref (GdkCursor *cursor) */
+void gdkperl_cursor_unref(SV* cursor)
+{
+    gdk_cursor_unref(SvGdkCursor(cursor));
+}
 
