@@ -1,16 +1,16 @@
 package Gtk2::Gtk2;
 
-# $Id: Gtk2.pm,v 1.4 2002/12/09 22:10:07 ggc Exp $
+# $Id: Gtk2.pm,v 1.5 2002/12/16 17:16:54 ggc Exp $
 # Copyright 2002, Gran Thyni, kirra.net
 # licensed with Lesser General Public License (LGPL)
 # see http://www.fsf.org/licenses/lgpl.txt
 # Contributor:
 # - Dermot Musgrove
 
-our $rcsid = '$Id: Gtk2.pm,v 1.4 2002/12/09 22:10:07 ggc Exp $';
+our $rcsid = '$Id: Gtk2.pm,v 1.5 2002/12/16 17:16:54 ggc Exp $';
 our $VERSION = $1 if $rcsid =~ /(\d+\.[\d\.]+)/;
 
-BEGIN { do 'Gtk2/_config.pm'; }
+BEGIN { do 'Gtk2/_config.pm'; $@ and die }
 
 use base qw(Gtk2::_Object);
 
