@@ -1,14 +1,14 @@
 package Gtk2::IMContext;
 
-# $Id: IMContext.pm,v 1.1 2002/11/11 16:55:48 gthyni Exp $a
+# $Id: IMContext.pm,v 1.2 2002/12/16 17:20:18 ggc Exp $a
 # Copyright 2002, Gran Thyni, kirra.net
 # licensed with Lesser General Public License (LGPL)
 # see http://www.fsf.org/licenses/lgpl.txt
 
-our $rcsid = '$Id: IMContext.pm,v 1.1 2002/11/11 16:55:48 gthyni Exp $';
+our $rcsid = '$Id: IMContext.pm,v 1.2 2002/12/16 17:20:18 ggc Exp $';
 our $VERSION = $1 if $rcsid =~ /(\d+\.[\d\.]+)/;
 
-#BEGIN { do 'Gtk2/_config.pm'; }
+#BEGIN { do 'Gtk2/_config.pm'; $@ and die }
 
 use Gtk2::GObject;
 @ISA=qw(Gtk2::GObject);
