@@ -1,14 +1,14 @@
 package Gtk2::ListItem;
 
-# $Id: ListItem.pm,v 1.6 2002/11/20 20:42:53 gthyni Exp $
+# $Id: ListItem.pm,v 1.7 2002/12/16 17:20:42 ggc Exp $
 # Copyright 2002, Marin Purgar
 # licensed under Lesser General Public License (LGPL)
 # see http://www.fsf.org/licenses/lgpl.txt
 
-our $rcsid = '$Id: ListItem.pm,v 1.6 2002/11/20 20:42:53 gthyni Exp $';
+our $rcsid = '$Id: ListItem.pm,v 1.7 2002/12/16 17:20:42 ggc Exp $';
 our $VERSION = $1 if $rcsid =~ /(\d+\.[\d\.]+)/;
 
-BEGIN { do 'Gtk2/_config.pm'; }
+BEGIN { do 'Gtk2/_config.pm'; $@ and die }
 
 use base qw(Gtk2::Item);
 
