@@ -1,13 +1,13 @@
 package Gtk2::Pango::Language;
 
-# $Id: Language.pm,v 1.3 2002/11/09 16:23:15 gthyni Exp $
+# $Id: Language.pm,v 1.4 2002/12/16 17:24:44 ggc Exp $
 # Copyright 2002, Gran Thyni, kirra.net
 # licensed with Lesser General Public License (LGPL)
 # see http://www.fsf.org/licenses/lgpl.txt
 
-our $rcsid = '$Id: Language.pm,v 1.3 2002/11/09 16:23:15 gthyni Exp $';
+our $rcsid = '$Id: Language.pm,v 1.4 2002/12/16 17:24:44 ggc Exp $';
 our $VERSION = $1 if $rcsid =~ /(\d+\.[\d\.]+)/;
 
-#BEGIN { do 'Gtk2/_config.pm'; }
+#BEGIN { do 'Gtk2/_config.pm'; $@ and die }
 
 1;
