@@ -15,24 +15,24 @@ package Gtk2::Pango::Layout;
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 #
-# $Id: Layout.pm,v 1.5 2002/11/14 21:31:56 gthyni Exp $
+# $Id: Layout.pm,v 1.7 2002/12/16 17:24:46 ggc Exp $
 #
 
-our $rcsid = '$Id: Layout.pm,v 1.5 2002/11/14 21:31:56 gthyni Exp $';
+our $rcsid = '$Id: Layout.pm,v 1.7 2002/12/16 17:24:46 ggc Exp $';
 our $VERSION = $1 if $rcsid =~ /(\d+\.[\d\.]+)/;
 
-BEGIN { do 'Gtk2/_config.pm'; }
+BEGIN { do 'Gtk2/_config.pm'; $@ and die }
 
 use Gtk2::GObject;
 @ISA = qw(Gtk2::GObject);
 
 sub get_size {
-    my $s = shift->_get_size();
+    my $s = shift->_get_size;
     return wantarray ? @$s : $s;
 }
 
 sub get_pixel_size {
-    my $s = shift->_get_pixel_size();
+    my $s = shift->_get_pixel_size;
     return wantarray ? @$s : $s;
 }
 
