@@ -1,14 +1,14 @@
 package Gtk2::Rc;
 
-# $Id: Rc.pm,v 1.2 2002/11/27 19:46:39 ggc Exp $
+# $Id: Rc.pm,v 1.3 2002/12/16 17:21:45 ggc Exp $
 # Copyright 2002, Gran Thyni, kirra.net
 # licensed with Lesser General Public License (LGPL)
 # see http://www.fsf.org/licenses/lgpl.txt
 
-our $rcsid = '$Id: Rc.pm,v 1.2 2002/11/27 19:46:39 ggc Exp $';
+our $rcsid = '$Id: Rc.pm,v 1.3 2002/12/16 17:21:45 ggc Exp $';
 our $VERSION = $1 if $rcsid =~ /(\d+\.[\d\.]+)/;
 
-BEGIN { do 'Gtk2/_config.pm'; }
+BEGIN { do 'Gtk2/_config.pm'; $@ and die }
 
 # not a GObject
 use Gtk2::_Object;
