@@ -1,14 +1,14 @@
 package Gtk2::TextBuffer;
 
-# $Id: TextBuffer.pm,v 1.9 2002/11/12 18:43:41 ggc Exp $
+# $Id: TextBuffer.pm,v 1.11 2002/12/16 17:22:40 ggc Exp $
 # Copyright 2002, Gran Thyni, kirra.net
 # licensed with Lesser General Public License (LGPL)
 # see http://www.fsf.org/licenses/lgpl.txt
 
-our $rcsid = '$Id: TextBuffer.pm,v 1.9 2002/11/12 18:43:41 ggc Exp $';
+our $rcsid = '$Id: TextBuffer.pm,v 1.11 2002/12/16 17:22:40 ggc Exp $';
 our $VERSION = $1 if $rcsid =~ /(\d+\.[\d\.]+)/;
 
-BEGIN { do 'Gtk2/_config.pm'; }
+BEGIN { do 'Gtk2/_config.pm'; $@ and die }
 
 use Gtk2::GObject;
 @ISA=qw(Gtk2::GObject);
@@ -17,7 +17,7 @@ use Gtk2::TextIter;
 use Gtk2::TextTag;
 
 sub get_bounds {
-    my $b = shift->_get_bounds();
+    my $b = shift->_get_bounds;
     return wantarray ? @$b : $b;
 }
 
