@@ -14,15 +14,15 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 #
-# $Id: TextTag.pm,v 1.3 2002/11/09 16:23:15 gthyni Exp $
+# $Id: TextTag.pm,v 1.4 2002/12/16 17:22:49 ggc Exp $
 #
 
 package Gtk2::TextTag;
 
-our $rcsid = '$Id: TextTag.pm,v 1.3 2002/11/09 16:23:15 gthyni Exp $';
+our $rcsid = '$Id: TextTag.pm,v 1.4 2002/12/16 17:22:49 ggc Exp $';
 our $VERSION = $1 if $rcsid =~ /(\d+\.[\d\.]+)/;
 
-#BEGIN { do 'Gtk2/_config.pm'; }
+#BEGIN { do 'Gtk2/_config.pm'; $@ and die }
 
 use Gtk2::GObject;
 @ISA=qw(Gtk2::GObject);
