@@ -1,14 +1,14 @@
 package Gtk2::Tree;
 
-# $Id: Tree.pm,v 1.2 2002/11/11 20:06:35 gthyni Exp $
+# $Id: Tree.pm,v 1.3 2002/12/16 17:23:24 ggc Exp $
 # Copyright 2002, Gran Thyni, kirra.net
 # licensed with Lesser General Public License (LGPL)
 # see http://www.fsf.org/licenses/lgpl.txt
 
-our $rcsid = '$Id: Tree.pm,v 1.2 2002/11/11 20:06:35 gthyni Exp $';
+our $rcsid = '$Id: Tree.pm,v 1.3 2002/12/16 17:23:24 ggc Exp $';
 our $VERSION = $1 if $rcsid =~ /(\d+\.[\d\.]+)/;
 
-#BEGIN { do 'Gtk2/_config.pm'; }
+#BEGIN { do 'Gtk2/_config.pm'; $@ and die }
 
 use Gtk2::Container;
 @ISA=qw(Gtk2::Container);
