@@ -1,14 +1,14 @@
 package Gtk2::TreeViewColumn;
 
-# $Id: TreeViewColumn.pm,v 1.7 2002/11/21 15:34:17 ggc Exp $
+# $Id: TreeViewColumn.pm,v 1.8 2002/12/16 17:23:33 ggc Exp $
 # Copyright 2002, Gran Thyni, kirra.net
 # licensed with Lesser General Public License (LGPL)
 # see http://www.fsf.org/licenses/lgpl.txt
 
-our $rcsid = '$Id: TreeViewColumn.pm,v 1.7 2002/11/21 15:34:17 ggc Exp $';
+our $rcsid = '$Id: TreeViewColumn.pm,v 1.8 2002/12/16 17:23:33 ggc Exp $';
 our $VERSION = $1 if $rcsid =~ /(\d+\.[\d\.]+)/;
 
-BEGIN { do 'Gtk2/_config.pm'; }
+BEGIN { do 'Gtk2/_config.pm'; $@ and die }
 
 use Gtk2::Object;
 @ISA=qw(Gtk2::Object);
