@@ -1,6 +1,6 @@
 package Gtk2::_Object;
 
-# $Id: _Object.pm,v 1.10 2002/11/28 14:24:32 ggc Exp $
+# $Id: _Object.pm,v 1.11 2003/01/12 22:50:41 joered Exp $
 # Copyright 2002, Gran Thyni, kirra.net
 # licensed with Lesser General Public License (LGPL)
 # see http://www.fsf.org/licenses/lgpl.txt
@@ -8,10 +8,12 @@ package Gtk2::_Object;
 # This is internal class which should be parent to
 # all classes in Gtk2, gobjects or not.
 
-our $rcsid = '$Id: _Object.pm,v 1.10 2002/11/28 14:24:32 ggc Exp $';
+our $rcsid = '$Id: _Object.pm,v 1.11 2003/01/12 22:50:41 joered Exp $';
 our $VERSION = $1 if $rcsid =~ /(\d+\.[\d\.]+)/;
 
-use vars qw($loader %loaded);
+use strict;
+use Carp;
+use vars qw($loader %loaded $AUTOLOAD);
 
 do 'Gtk2/_loader.pm';
 
@@ -44,7 +46,13 @@ sub AUTOLOAD
     eval "use $class";
     die $@ if $@;
     my $func = (split /::/, $AUTOLOAD)[-1];
-    $class->$func(@_);
+    my $rc = eval { $class->$func(@_) };
+    if ( $@ ) {
+	my $exc = $@;
+	$exc =~ s/\s+at\s+.*?line\s+\d+\.\n$//;
+	croak $exc;
+    }
+    return $rc;
   }
 
 1;
