@@ -1,4 +1,4 @@
-/* $Id: Alignment.c,v 1.4 2002/10/20 15:53:32 ggc Exp $
+/* $Id: Alignment.c,v 1.5 2003/01/16 21:24:03 joered Exp $
  * Copyright 2002, Gran Thyni, kirra.net
  * licensed with Lesser General Public License (LGPL)
  * see http://www.fsf.org/licenses/lgpl.txt
@@ -6,7 +6,7 @@
 
 #include "gtk2-perl.h"
 
-SV* gtkperl_alignment_new(char* class, double xalign, double yalign, double xscale, double yscale)
+SV* gtkperl_alignment__new(char* class, double xalign, double yalign, double xscale, double yscale)
 {
     return gtk2_perl_new_object(gtk_alignment_new(xalign, yalign, xscale, yscale));
 }
