@@ -1,4 +1,4 @@
-/* $Id: HBox.c,v 1.3 2002/10/20 15:53:32 ggc Exp $
+/* $Id: HBox.c,v 1.4 2003/01/16 21:24:03 joered Exp $
  * Copyright 2002, Gran Thyni, kirra.net
  * licensed with Lesser General Public License (LGPL)
  * see http://www.fsf.org/licenses/lgpl.txt
@@ -6,7 +6,7 @@
 
 #include "gtk2-perl.h"
 
-SV* gtkperl_hbox_new(char* class, int homogeneous, int spacing)
+SV* gtkperl_hbox__new(char* class, int homogeneous, int spacing)
 {
     return gtk2_perl_new_object(gtk_hbox_new(homogeneous != 0, spacing));
 }
